@@ -586,16 +586,10 @@ class BaseAPResultCollection(object):
             is_state = row['county_number'] == '1'
             county_number = str(row['county_number'])
             
-            # AP stupidly strips leading 0s in the FIPS for the 
-            # results file. This fixes em.
-#            if is_state:
-#                fips = '00000'
-#            else:
-#                if self.leading_zero_fips and fips[0] != '0':
-#                    fips = '0' + fips
-            
             # Pull the reporting unit
-            reporting_unit = race.get_reporting_unit("%s%s" % (row['county_name'], county_number))
+            reporting_unit = race.get_reporting_unit(
+                "%s%s" % (row['county_name'], county_number)
+            )
             # Loop through all the candidates
             votes_cast = 0
             for cand in row['candidates']:
@@ -635,6 +629,7 @@ class BaseAPResultCollection(object):
                 reporting_unit.update_result(result)
                 
             # Update the reporting unit's precincts status
+            reporting_unit.precincts_total = int(row['total_precincts'])
             reporting_unit.precincts_reporting = int(row['precincts_reporting'])
             reporting_unit.precincts_reporting_percent = calculate.percentage(
                 reporting_unit.precincts_reporting,
@@ -652,6 +647,7 @@ class BaseAPResultCollection(object):
                     votes_cast
                 )
 
+
 class State(BaseAPResultCollection):
     """
     One of these United States.
